${ "The title is {2} {1} {0}!".format( {'nohtyP'}.pop()[::-1], list({'from': 'idontmatter'}).pop(), {'ohea': 'generated', 'rtns': 'kcwb'}['ohea'], )} And more text. "abc

The span around this always gets stripped. Content in a span only if foo was not defined. This is a literal dolars sign before `not_a_var`: `$$not_a_var` $a

- $x is divisible by 3
- ${x} is not divisible by 3, but it is divisible by ${y}!

${value_of('somevar', 'somevar is not set')} ${Markup('1234&')}
- ${i} divides by 3
- ${i} is not a friend of 3
- ${i} aspires to be a number that divides by 3

${divfunc(i)}

${_('')}